import { WithRequest } from './util';
/**
 * TODO: Enable commented-out methods when they are implemented
 * blockchain-side.
 */
export declare const enum RPCMethod {
    GetNetworkId = "GetNetworkId",
    GetBlockchainInfo = "GetBlockchainInfo",
    GetShardingStructure = "GetShardingStructure",
    GetDSBlock = "GetDSBlock",
    GetLatestDSBlock = "GetLatestDsBlock",
    GetNumDSBlocks = "GetNumDSBlocks",
    GetDSBlockRate = "GetDSBlockRate",
    DSBlockListing = "DSBlockListing",
    GetTxBlock = "GetTSBlock",
    GetLatestTxBlock = "GetLatestTxBlock",
    GetNumTxBlocks = "GetNumTxBlocks",
    GetTxBlockRate = "GetTxBlockRate",
    TxBlockListing = "TxBlockListing",
    GetNumTransactions = "GetNumTransactions",
    GetTransactionRate = "GetTransactionRate",
    GetCurrentMiniEpoch = "GetCurrentMiniEpoch",
    GetCurrentDSEpoch = "GetCurrentDSEpoch",
    CreateTransaction = "CreateTransaction",
    GetTransaction = "GetTransaction",
    GetRecentTransactions = "GetRecentTransactions",
    GetNumTxnsTxEpoch = "GetNumTxnsTxEpoch",
    GetNumTxnsDSEpoch = "GetNumTxnsDSEpoch",
    GetSmartContractCode = "GetSmartContractCode",
    GetSmartContractInit = "GetSmartContractInit",
    GetSmartContractState = "GetSmartContractState",
    GetContractAddressFromTransactionID = "GetContractAddressFromTransactionID",
    GetBalance = "GetBalance"
}
export interface RPCRequestPayload<T> {
    id: 1;
    jsonrpc: '2.0';
    method: RPCMethod;
    params: T;
}
interface RPCRequestOptions {
    headers?: Headers;
    method?: string;
}
export interface RPCRequest<T> {
    url: string;
    payload: RPCRequestPayload<T>;
    options?: RPCRequestOptions;
}
export interface RPCResponseSuccess<R = any> {
    result: R;
}
export interface RPCResponseError<E> {
    result: {
        error: E;
        Error: E;
    };
}
export declare type RPCResponse<R, E> = RPCResponseSuccess<R> | RPCResponseError<E>;
export declare type RPCResponseHandler<R, E, T> = (response: WithRequest<RPCResponse<R, E>>) => T;
export declare const performRPC: <R, E, D extends any[], T = RPCResponse<R, E>>(request: RPCRequest<D>, handler: RPCResponseHandler<R, E, T>) => Promise<T>;
export {};
//# sourceMappingURL=net.d.ts.map